@@ -20,7 +20,7 @@ sub register {
         return $next->() unless $c->stash->{format} and $c->stash->{format} eq 'pdf';
         $c->respond_to( pdf => sub {
             my $url  = $c->req->url->to_abs;
-               $url =~ s/\.pdf.*$//i;
+               $url =~ s/\.pdf($|\?)/$1/i;
 
             $app->log->debug( "...fetching url $url for pdf" );
 
@@ -101,7 +101,7 @@ Mojolicious::Plugin::PDFRenderer - Uses wkhtmltopdf via PDF::WebKit to render yo
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -168,13 +168,27 @@ L<https://github.com/sharabash/mojolicious-plugin-pdfrenderer>
 
 Nour Sharabash <amirite@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
 
 Nour Sharabash <nour.sharabash@gmail.com>
 
+=item *
+
+Nour Sharabash <nour@hellosign.com>
+
+=item *
+
+gabriele.ceranto <gabriele.ceranto@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Nour Sharabash.
+This software is copyright (c) 2016 by Nour Sharabash.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
